@@ -649,10 +649,10 @@ ags_count_beats_audio_run_class_init(AgsCountBeatsAudioRunClass *count_beats_aud
 void
 ags_count_beats_audio_run_init(AgsCountBeatsAudioRun *count_beats_audio_run)
 {
-  ags_recall_set_ability_flags(count_beats_audio_run, (AGS_SOUND_ABILITY_SEQUENCER |
-						       AGS_SOUND_ABILITY_NOTATION |
-						       AGS_SOUND_ABILITY_WAVE |
-						       AGS_SOUND_ABILITY_MIDI));
+  ags_recall_set_ability_flags((AgsRecall *) count_beats_audio_run, (AGS_SOUND_ABILITY_SEQUENCER |
+								     AGS_SOUND_ABILITY_NOTATION |
+								     AGS_SOUND_ABILITY_WAVE |
+								     AGS_SOUND_ABILITY_MIDI));
 
   g_signal_connect_after(count_beats_audio_run, "notify::output-soundcard",
 			 G_CALLBACK(ags_count_beats_audio_run_notify_output_soundcard_callback), NULL);
@@ -730,7 +730,7 @@ ags_count_beats_audio_run_set_property(GObject *gobject,
 
       /* check template */
       if(delay_audio_run != NULL &&
-	 ags_recall_test_flags(delay_audio_run, AGS_RECALL_TEMPLATE)){
+	 ags_recall_test_flags((AgsRecall *) delay_audio_run, AGS_RECALL_TEMPLATE)){
 	is_template = TRUE;
       }else{
 	is_template = FALSE;
@@ -738,12 +738,26 @@ ags_count_beats_audio_run_set_property(GObject *gobject,
 
       /* old - dependency/connection */
       if(is_template){
-	ags_recall_remove_recall_dependency(AGS_RECALL(count_beats_audio_run),
-					    (AgsRecall *) old_delay_audio_run);
+	if(old_delay_audio_run != NULL){
+	  AgsRecallDependency *recall_dependency;
+
+	  GList *list;
+	  
+	  recall_dependency = NULL;
+	  list = ags_recall_dependency_find_dependency(AGS_RECALL(count_beats_audio_run)->recall_dependency,
+						       old_delay_audio_run);
+
+	  if(list != NULL){
+	    recall_dependency = list->data;
+	  }
+	  
+	  ags_recall_remove_recall_dependency(AGS_RECALL(count_beats_audio_run),
+					      recall_dependency);
+	}
       }else{
 	if(ags_connectable_is_connected(AGS_CONNECTABLE(count_beats_audio_run))){
 	  ags_connectable_disconnect_connection(AGS_CONNECTABLE(count_beats_audio_run),
-						old_delay_audio_run);
+						(GObject *) old_delay_audio_run);
 	}
       }
 
@@ -761,7 +775,7 @@ ags_count_beats_audio_run_set_property(GObject *gobject,
 	}else{
 	  if(ags_connectable_is_connected(AGS_CONNECTABLE(count_beats_audio_run))){
 	    ags_connectable_connect_connection(AGS_CONNECTABLE(count_beats_audio_run),
-					       delay_audio_run);
+					       (GObject *) delay_audio_run);
 	  }
 	}
       }
@@ -949,7 +963,7 @@ ags_count_beats_audio_run_connect(AgsConnectable *connectable)
 	       NULL);
 
   ags_connectable_connect_connection(connectable,
-				     delay_audio_run);  
+				     (GObject *) delay_audio_run);  
 }
 
 void
@@ -971,7 +985,7 @@ ags_count_beats_audio_run_disconnect(AgsConnectable *connectable)
 	       NULL);
 
   ags_connectable_disconnect_connection(connectable,
-					delay_audio_run);  
+					(GObject *) delay_audio_run);  
 }
 
 void
@@ -991,7 +1005,7 @@ ags_count_beats_audio_run_connect_connection(AgsConnectable *connectable,
 	       "delay-audio-run", &delay_audio_run,
 	       NULL);
 
-  if(delay_audio_run == connection){
+  if((GObject *) delay_audio_run == connection){
     g_signal_connect(G_OBJECT(count_beats_audio_run->delay_audio_run), "wave-alloc-output",
 		     G_CALLBACK(ags_count_beats_audio_run_wave_alloc_output_callback), count_beats_audio_run);
 
@@ -1029,7 +1043,7 @@ ags_count_beats_audio_run_disconnect_connection(AgsConnectable *connectable,
 	       "delay-audio-run", &delay_audio_run,
 	       NULL);
 
-  if(delay_audio_run == connection){
+  if((GObject *) delay_audio_run == connection){
     g_object_disconnect(delay_audio_run,
 			"any_signal::wave-alloc-output",
 			G_CALLBACK(ags_count_beats_audio_run_wave_alloc_output_callback),
