@@ -228,7 +228,7 @@ ags_route_dssi_audio_run_class_init(AgsRouteDssiAudioRunClass *route_dssi_audio_
 void
 ags_route_dssi_audio_run_init(AgsRouteDssiAudioRun *route_dssi_audio_run)
 {
-  ags_recall_set_ability_flags(route_dssi_audio_run, (AGS_SOUND_ABILITY_NOTATION));
+  ags_recall_set_ability_flags((AgsRecall *) route_dssi_audio_run, (AGS_SOUND_ABILITY_NOTATION));
 
   AGS_RECALL(route_dssi_audio_run)->name = "ags-route-dssi";
   AGS_RECALL(route_dssi_audio_run)->version = AGS_RECALL_DEFAULT_VERSION;
@@ -280,7 +280,8 @@ ags_route_dssi_audio_run_set_property(GObject *gobject,
       gboolean is_template;
 
       delay_audio_run = g_value_get_object(value);
-
+      old_delay_audio_run = NULL;
+      
       pthread_mutex_lock(recall_mutex);
 
       if(delay_audio_run == route_dssi_audio_run->delay_audio_run){
@@ -303,7 +304,7 @@ ags_route_dssi_audio_run_set_property(GObject *gobject,
 
       /* check template */
       if(delay_audio_run != NULL &&
-	 ags_recall_test_flags(route_dssi_audio_run, AGS_RECALL_TEMPLATE)){
+	 ags_recall_test_flags((AgsRecall *) route_dssi_audio_run, AGS_RECALL_TEMPLATE)){
 	is_template = TRUE;
       }else{
 	is_template = FALSE;
@@ -311,12 +312,26 @@ ags_route_dssi_audio_run_set_property(GObject *gobject,
 
       /* old - dependency/connection */
       if(is_template){
-	ags_recall_remove_recall_dependency(AGS_RECALL(route_dssi_audio_run),
-					    (AgsRecall *) old_delay_audio_run);
+	if(old_delay_audio_run != NULL){
+	  AgsRecallDependency *recall_dependency;
+
+	  GList *list;
+	  
+	  recall_dependency = NULL;
+	  list = ags_recall_dependency_find_dependency(AGS_RECALL(route_dssi_audio_run)->recall_dependency,
+						       old_delay_audio_run);
+
+	  if(list != NULL){
+	    recall_dependency = list->data;
+	  }
+	  
+	  ags_recall_remove_recall_dependency(AGS_RECALL(route_dssi_audio_run),
+					      recall_dependency);
+	}
       }else{
 	if(ags_connectable_is_connected(AGS_CONNECTABLE(route_dssi_audio_run))){
 	  ags_connectable_disconnect_connection(AGS_CONNECTABLE(route_dssi_audio_run),
-						old_delay_audio_run);
+						(GObject *) old_delay_audio_run);
 	}
       }
 
@@ -334,7 +349,7 @@ ags_route_dssi_audio_run_set_property(GObject *gobject,
 	}else{
 	  if(ags_connectable_is_connected(AGS_CONNECTABLE(route_dssi_audio_run))){
 	    ags_connectable_connect_connection(AGS_CONNECTABLE(route_dssi_audio_run),
-					       delay_audio_run);
+					       (GObject *) delay_audio_run);
 	  }
 	}
       }
@@ -347,7 +362,8 @@ ags_route_dssi_audio_run_set_property(GObject *gobject,
       gboolean is_template;
 
       count_beats_audio_run = g_value_get_object(value);
-
+      old_count_beats_audio_run = NULL;
+      
       pthread_mutex_lock(recall_mutex);
 
       if(count_beats_audio_run == route_dssi_audio_run->count_beats_audio_run){
@@ -363,6 +379,8 @@ ags_route_dssi_audio_run_set_property(GObject *gobject,
       }
 
       if(route_dssi_audio_run->count_beats_audio_run != NULL){
+	old_count_beats_audio_run = route_dssi_audio_run->count_beats_audio_run;
+
 	g_object_unref(G_OBJECT(route_dssi_audio_run->count_beats_audio_run));
       }
 
@@ -376,17 +394,30 @@ ags_route_dssi_audio_run_set_property(GObject *gobject,
 
       /* check template */
       if(count_beats_audio_run != NULL &&
-	 ags_recall_test_flags(route_dssi_audio_run, AGS_RECALL_TEMPLATE)){
+	 ags_recall_test_flags((AgsRecall *) route_dssi_audio_run, AGS_RECALL_TEMPLATE)){
 	is_template = TRUE;
       }else{
 	is_template = FALSE;
       }
 
       /* dependency - remove */
-      if(is_template &&
-	 old_count_beats_audio_run != NULL){
-	ags_recall_remove_recall_dependency(AGS_RECALL(route_dssi_audio_run),
-					    (AgsRecall *) old_count_beats_audio_run);
+      if(is_template){
+	if(old_count_beats_audio_run != NULL){
+	  AgsRecallDependency *recall_dependency;
+
+	  GList *list;
+	  
+	  recall_dependency = NULL;
+	  list = ags_recall_dependency_find_dependency(AGS_RECALL(route_dssi_audio_run)->recall_dependency,
+						       old_count_beats_audio_run);
+
+	  if(list != NULL){
+	    recall_dependency = list->data;
+	  }
+	  
+	  ags_recall_remove_recall_dependency(AGS_RECALL(route_dssi_audio_run),
+					      recall_dependency);
+	}
       }
 
       /* dependency - add */
@@ -525,7 +556,7 @@ ags_route_dssi_audio_run_connect(AgsConnectable *connectable)
 	       "delay-audio-run", &delay_audio_run,
 	       NULL);
 
-  ags_connectable_connect_connection(connectable, delay_audio_run);
+  ags_connectable_connect_connection(connectable, (GObject *) delay_audio_run);
   
   /* call parent */
   ags_route_dssi_audio_run_parent_connectable_interface->connect(connectable);
@@ -547,7 +578,7 @@ ags_route_dssi_audio_run_disconnect(AgsConnectable *connectable)
 	       "delay-audio-run", &delay_audio_run,
 	       NULL);
 
-  ags_connectable_disconnect_connection(connectable, delay_audio_run);
+  ags_connectable_disconnect_connection(connectable, (GObject *) delay_audio_run);
 
   /* call parent */
   ags_route_dssi_audio_run_parent_connectable_interface->disconnect(connectable);
@@ -569,7 +600,7 @@ ags_route_dssi_audio_run_connect_connection(AgsConnectable *connectable, GObject
 	       "delay-audio-run", &delay_audio_run,
 	       NULL);
 
-  if(connection == delay_audio_run){
+  if(connection == (GObject *) delay_audio_run){
     g_signal_connect(G_OBJECT(delay_audio_run), "notation-alloc-input",
 		     G_CALLBACK(ags_route_dssi_audio_run_alloc_input_callback), route_dssi_audio_run);  
   }
@@ -591,7 +622,7 @@ ags_route_dssi_audio_run_disconnect_connection(AgsConnectable *connectable, GObj
 	       "delay-audio-run", &delay_audio_run,
 	       NULL);
 
-  if(connection == delay_audio_run){
+  if(connection == (GObject *) delay_audio_run){
     g_object_disconnect(G_OBJECT(delay_audio_run),
 			"any_signal::notation-alloc-input",
 			G_CALLBACK(ags_route_dssi_audio_run_alloc_input_callback),
